@@ -14,10 +14,11 @@ use English qw/ -no_match_vars /;
 
 extends 'App::VTide::Command::Run';
 
-our $VERSION = version->new('0.1.15');
+our $VERSION = version->new('0.1.16');
 our $NAME    = 'edit';
 our $OPTIONS = [
     'test|T!',
+    'save|s=s',
     'verbose|v+',
 ];
 sub details_sub { return ( $NAME, $OPTIONS )};
@@ -47,8 +48,16 @@ sub run {
     $self->runit( @cmd );
 
     $params = $self->params($ENV{VTIDE_TERM} || '1');
+
+    my $title = $params->{title} || 'bash';
+    my $max = 15;
+    if (length $title > $max) {
+        $title = substr $title, (length $title) - $max, $max + 1;
+    }
+
     eval { require Term::Title; }
-        and Term::Title::set_titlebar($params->{title} || 'bash');
+        and Term::Title::set_titlebar($title);
+    system 'tmux', 'rename-window', $title;
 
     return;
 }
@@ -91,7 +100,7 @@ App::VTide::Command::Edit - Run an edit command (like Run but without a terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Edit version 0.1.15
+This documentation refers to App::VTide::Command::Edit version 0.1.16
 
 =head1 SYNOPSIS
 
